@@ -45,8 +45,8 @@ class QuickBooks(object):
     _BUSINESS_OBJECTS = [
         "Account", "Attachable", "Bill", "BillPayment",
         "Class", "CreditMemo", "Customer", "CompanyCurrency",
-        "Department", "Deposit", "Employee", "Estimate", "Invoice",
-        "Item", "JournalEntry", "Payment", "PaymentMethod",
+        "Department", "Deposit", "Employee", "Estimate", "ExchangeRate", "Invoice",
+        "Item", "JournalEntry", "Payment", "PaymentMethod", "Preferences",
         "Purchase", "PurchaseOrder", "RefundReceipt",
         "SalesReceipt", "TaxAgency", "TaxCode", "TaxService/Taxcode", "TaxRate", "Term",
         "TimeActivity", "Transfer", "Vendor", "VendorCredit", "CreditCardPayment",
@@ -77,7 +77,8 @@ class QuickBooks(object):
             else:
                 instance.sandbox = False
 
-            instance._start_session()
+            refresh_token = instance._start_session()
+            instance.refresh_token = refresh_token
 
         if 'company_id' in kwargs:
             instance.company_id = kwargs['company_id']
@@ -99,6 +100,7 @@ class QuickBooks(object):
             client_secret=self.auth_client.client_secret,
             access_token=self.auth_client.access_token,
         )
+        return self.auth_client.refresh_token
 
     @classmethod
     def get_instance(cls):
@@ -255,7 +257,12 @@ class QuickBooks(object):
 
         return result
 
-    def handle_exceptions(self, results):
+    @staticmethod
+    def handle_exceptions(results):
+        """
+        Error codes with description in documentation:
+        https://developer.intuit.com/app/developer/qbo/docs/develop/troubleshooting/error-codes#id1
+        """
         # Needs to handle multiple errors
         for error in results["Error"]:
 
@@ -269,17 +276,17 @@ class QuickBooks(object):
             if "code" in error:
                 code = int(error["code"])
 
-            if code > 0 and code <= 499:
+            if 0 < code <= 499:
                 raise exceptions.AuthorizationException(message, code, detail)
-            elif code >= 500 and code <= 599:
+            elif 500 <= code <= 599:
                 raise exceptions.UnsupportedException(message, code, detail)
-            elif code >= 600 and code <= 1999:
+            elif 600 <= code <= 1999:
                 if code == 610:
                     raise exceptions.ObjectNotFoundException(message, code, detail)
                 raise exceptions.GeneralException(message, code, detail)
-            elif code >= 2000 and code <= 4999:
+            elif 2000 <= code <= 4999:
                 raise exceptions.ValidationException(message, code, detail)
-            elif code >= 10000:
+            elif 10000 <= code:
                 raise exceptions.SevereException(message, code, detail)
             else:
                 raise exceptions.QuickbooksException(message, code, detail)
